@@ -4,6 +4,7 @@ library(tiledb)
 ctx <- tiledb_ctx(limitTileDBCores())
 
 isOldWindows <- Sys.info()[["sysname"]] == "Windows" && grepl('Windows Server 2008', osVersion)
+isWindows <- Sys.info()[["sysname"]] == "Windows"
 
 #test_that("tiledb_attr constructor works", {
 a1 <- tiledb_attr(type = "FLOAT64")
@@ -53,7 +54,7 @@ expect_true(is.na(tiledb::cell_val_num(attrs)))
 #})
 
 #test_that("tiledb_attr set fill", {
-if (tiledb_version(TRUE) < "2.1.0") exit_file("Needs TileDB 2.1.* or later")
+if (tiledb_version(TRUE) < "2.7.0") exit_file("Needs TileDB 2.7.* or later")
 if (isOldWindows) exit_file("skip remainder of this file on old Windows releases")
 
 ## test for default
@@ -142,7 +143,7 @@ attrib <- c(tiledb_attr("year",  type = "DATETIME_YEAR"),  # year
 schema <- tiledb_array_schema(domain, attrib, sparse=TRUE)
 res <- tiledb_array_create(uri, schema)
 
-arr <- tiledb_array(uri, as.data.frame=TRUE)
+arr <- tiledb_array(uri, return_as="data.frame")
 
 dvec <- 1:3
 data <- data.frame(row = dvec,
@@ -162,7 +163,7 @@ data <- data.frame(row = dvec,
                    )
 
 arr[] <- data
-arr2 <- tiledb_array(uri, as.data.frame=TRUE)
+arr2 <- tiledb_array(uri, return_as="data.frame")
 readdata <- arr2[]
 expect_true(all.equal(data, readdata, check.attributes=FALSE))
 
@@ -217,7 +218,7 @@ df <- data.frame(row     =  1:10,
 arr <- tiledb_array(uri)
 arr[] <- df
 
-newarr <- tiledb_array(uri, as.data.frame=TRUE)
+newarr <- tiledb_array(uri, return_as="data.frame")
 chk <- newarr[]
 expect_equal(df[,1:10], chk[,1:10])
 expect_equivalent(as.numeric(df[,11]), chk[,11]) # we currently return uint64_t as numeric
@@ -256,4 +257,4 @@ expect_equal(tiledb_query_status(qry), "COMPLETE")
 arr2 <- tiledb_array(uri, return_as="data.frame")
 res2 <- arr2[0:3]
 attr(res2, "query_status") <- NULL
-expect_equal(v, res2[,"val"])
+if (!isWindows) expect_equal(v, res2[,"val"])
