@@ -44,11 +44,11 @@ while (deltat < 30) {
     ## we need an 'epsilon' because when we record 'times' is not exactly where the array timestamp is
     epst <- deltat/2
 
-    res1 <- tiledb_array(uri, as.data.frame=TRUE)[]							 		# no limits
-    res2 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_start=times[1]-epst, timestamp_end=times[2]+epst)[]    # end after 2nd timestamp
-    res3 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_start=times[4]+epst)[] 	# start after fourth
-    res4 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_end=times[3]-epst)[]    # end before 3rd
-    res5 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_start=times[2]-epst, timestamp_end=times[3]+epst)[]
+    res1 <- tiledb_array(uri, return_as="data.frame")[]							 		# no limits
+    res2 <- tiledb_array(uri, return_as="data.frame", timestamp_start=times[1]-epst, timestamp_end=times[2]+epst)[]    # end after 2nd timestamp
+    res3 <- tiledb_array(uri, return_as="data.frame", timestamp_start=times[4]+epst)[] 	# start after fourth
+    res4 <- tiledb_array(uri, return_as="data.frame", timestamp_end=times[3]-epst)[]    # end before 3rd
+    res5 <- tiledb_array(uri, return_as="data.frame", timestamp_start=times[2]-epst, timestamp_end=times[3]+epst)[]
 
     if (isTRUE(all.equal(NROW(res1), 40)) &&                    # all four groups
         isTRUE(all.equal(NROW(res2), 20)) &&		            # expect group one + two (20 elements)
@@ -67,20 +67,20 @@ while (deltat < 30) {
 
 if (!success) exit_file("Issue with time traveling")
 
-res1 <- tiledb_array(uri, as.data.frame=TRUE)[] 		# no limits
+res1 <- tiledb_array(uri, return_as="data.frame")[] 		# no limits
 expect_equal(NROW(res1), 40)                            # all four observations
 
-res2 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_start=times[1]-epst, timestamp_end=times[2]+epst)[]    # end before 1st timestamp
+res2 <- tiledb_array(uri, return_as="data.frame", timestamp_start=times[1]-epst, timestamp_end=times[2]+epst)[]    # end before 1st timestamp
 expect_equal(NROW(res2), 20)            # expect group one and two (20 elements)
 
-res3 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_start=times[4]+epst)[] # start after fourth
+res3 <- tiledb_array(uri, return_as="data.frame", timestamp_start=times[4]+epst)[] # start after fourth
 expect_equal(NROW(res3), 0)             # expect zero data
 
-res4 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_end=times[3]-epst)[]    # end before 3rd
+res4 <- tiledb_array(uri, return_as="data.frame", timestamp_end=times[3]-epst)[]    # end before 3rd
 expect_equal(NROW(res4), 20)            # expect 2 groups, 20 obs
 expect_equal(max(res4$grp), 2)          # with groups being 1 and 2
 
-res5 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_start=times[2]-epst, timestamp_end=times[3]+epst)[]
+res5 <- tiledb_array(uri, return_as="data.frame", timestamp_start=times[2]-epst, timestamp_end=times[3]+epst)[]
 expect_equal(NROW(res5), 20)            # expects 2 groups, 2 and 3, with 20 obs
 expect_equal(min(res5$grp), 2)
 expect_equal(max(res5$grp), 3)
@@ -93,11 +93,11 @@ expect_equal(n, 4)
 times <- do.call(c, lapply(seq_len(n), function(i) tiledb_fragment_info_get_timestamp_range(fi, i-1)[1]))
 
 epstsml <- 0.005
-res1 <- tiledb_array(uri, as.data.frame=TRUE)[]						# no limits
-res2 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_end=times[1]+epstsml)[]    	# end after 1st timestamp
-res3 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_start=times[4]+epstsml)[]  	# start after fourth
-res4 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_end=times[3]-epstsml)[]    	# end before 3rd
-res5 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_start=times[2]-epstsml, timestamp_end=times[3]+epstsml)[]
+res1 <- tiledb_array(uri, return_as="data.frame")[]						# no limits
+res2 <- tiledb_array(uri, return_as="data.frame", timestamp_end=times[1]+epstsml)[]    	# end after 1st timestamp
+res3 <- tiledb_array(uri, return_as="data.frame", timestamp_start=times[4]+epstsml)[]  	# start after fourth
+res4 <- tiledb_array(uri, return_as="data.frame", timestamp_end=times[3]-epstsml)[]    	# end before 3rd
+res5 <- tiledb_array(uri, return_as="data.frame", timestamp_start=times[2]-epstsml, timestamp_end=times[3]+epstsml)[]
 expect_equal(NROW(res1), 40)
 expect_equal(NROW(res2), 10)		            # expect group one (10 elements)
 expect_equal(NROW(res3), 0)			            # expect zero data
@@ -125,3 +125,38 @@ array_consolidate(uri, start_time=times[1]-0.5, end_time=times[3])
 array_vacuum(uri, start_time=times[1]-0.5, end_time=times[3])
 ndircons2 <- tiledb_vfs_ls(uridir, vfs=vfs)
 expect_true(length(ndircons2) < length(ndircons))
+
+## time-travel via policy object
+if (tiledb_version(TRUE) < "2.15.0") exit_file("Needs TileDB 2.15.* or later")
+
+uri <- tempfile()
+ts <- function(x) as.POSIXct(x/1000, tz="UTC", origin="1970-01-01")
+D <- data.frame(ind = 1L, val = 1.0)
+fromDataFrame(D, uri, col_index = 1, mode = "schema_only")
+for (tstamp in 1:3) {
+    arr <- tiledb_array(uri, "WRITE", timestamp_end = ts(tstamp))
+    arr[] <- data.frame(ind=1, val=tstamp)
+}
+
+## Unconstrained, expect all 3
+expect_equal(tiledb_array(uri, return_as="data.frame")[]$val, c(1,2,3))
+
+## Interval (1,2), expect 1 to 2
+expect_equal(tiledb_array(uri, return_as="data.frame",
+                          timestamp_start=ts(1), timestamp_end=ts(2))[]$val, c(1,2))
+
+## Interval (2,3), expect 2 to 3
+expect_equal(tiledb_array(uri, return_as="data.frame",
+                          timestamp_start=ts(2), timestamp_end=ts(3))[]$val, c(2,3))
+
+## Endpoint 1, expect 1
+expect_equal(tiledb_array(uri, return_as="data.frame", timestamp_end=ts(1))[]$val, 1)
+
+## Interval (1, ) expect 1 to 3
+expect_equal(tiledb_array(uri, return_as="data.frame", timestamp_start=ts(1))[]$val, c(1,2,3))
+
+## Also check fragment_info
+fi <- tiledb_fragment_info(uri)
+expect_equal(as.numeric(tiledb_fragment_info_get_timestamp_range(fi,0))*1000, c(1,1))
+expect_equal(as.numeric(tiledb_fragment_info_get_timestamp_range(fi,1))*1000, c(2,2))
+expect_equal(as.numeric(tiledb_fragment_info_get_timestamp_range(fi,2))*1000, c(3,3))
